#!/usr/bin/perl
#=======================================================================
# FileName : cmd_AileHttpAlarm.pl
# Summary  : HTTPアラーム通知ベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2018/06/04 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use File::Copy;
use Data::Dumper;
use Socket;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

#=======================================================================
# FuncName : main
# Summary  : HTTPアラーム通知メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2018/06/04 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile   = $_[0];
    my $resFile   = $_[1];
    my $requestData = "";
    my $json = "";
    my %responseData = ();
    my %conf      = ();
    my $logLevel = "";
    my $logmsg = "";
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";
    my $key = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        $requestData = CmdComFunc::readRequestFile($reqFile);
    }

    # 入力チェック
    if($rc == ComConst::STS_OK){
        # cgi側でチェックしているのでコマンド側でのチェックはなし
    }

    # 機能制限チェック
    if($rc == ComConst::STS_OK){
        # aileunの状態にかかわらず受信するため、機能制限はしない
    }

    # データ作成
    if($rc == ComConst::STS_OK){
        # Unix domainで通信する
        my $server_sock;
        # socket作成
        socket($server_sock, AF_UNIX, SOCK_STREAM, 0);
        if (!$server_sock) {
            $rc = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_STS} = $rc;
            $responseData{ComConst::JSON_KEY_MSG} = "Socketの作成に失敗しました";
        } else {
            # 接続
            my $ret_connect = connect($server_sock, pack_sockaddr_un(ComConst::HTTP_ALARM_SOCK_PATH));
            if ($ret_connect) {
                # 書き込み
                printf($server_sock "%c", $requestData->[0]->{ViewCH});
            } else {
                $rc = ComConst::STS_NG;
                $responseData{ComConst::JSON_KEY_STS} = $rc;
                $responseData{ComConst::JSON_KEY_MSG} = "サーバーへの接続に失敗しました";
            }
            # 切断
            close($server_sock);
        }
    }

    # レスポンスファイル出力
    $rc = CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});
    return $rc;
}
