#!/usr/bin/perl
#=======================================================================
# FileName : cmd_ShutdownSystem.pl
# Summary  : シャットダウンベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use File::Copy;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

#=======================================================================
# FuncName : main
# Summary  : シャットダウンメイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile   = $_[0];
    my $resFile   = $_[1];
    my $requestData = "";
    my %responseData = ();
    my %conf      = ();
    my $json = "";
    my $pid;
    my $logmsg;

    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    $pid = fork();
    if($pid){
        # 親プロセス
        ComLog::log_output(ComLog::LOG_DEBUG, sprintf($messages{CM192I003}, $pid));
        # リクエスト読み込み(なし)
        if($rc == ComConst::STS_OK){
        }

        # 入力チェック(なし)
        if($rc == ComConst::STS_OK){
        }

        if($rc == ComConst::STS_OK){
            ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM192I002});
        }
        # レスポンスファイル出力
        CmdComFunc::writeResponseFile($resFile, \%responseData);

        # 終了ログ出力
        ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});
    }else{
        # 子プロセス
        # 標準出力を閉じないと、親プロセスが子プロセスを待つので閉じておく
        close(STDOUT);
        sleep(ComConst::SHUTDOWN_WAIT_TIME);
        #if(ComConst::EXEC_SYSTEM){
        #    exec(`$shutdownShell`);
        #}
    }
    return $rc;
}
